from django import forms
from edc_action_item.forms import ActionItemCrfFormMixin
from edc_crf.modelform_mixins import CrfModelFormMixin

from ..form_validators import EgfrDropNotificationFormValidator
from ..models import EgfrDropNotification


class EgfrDropNotificationForm(CrfModelFormMixin, ActionItemCrfFormMixin, forms.ModelForm):
    form_validator_cls = EgfrDropNotificationFormValidator

    class Meta(ActionItemCrfFormMixin.Meta):
        model = EgfrDropNotification
        fields = "__all__"



from .ae import AeListboardView, DeathReportListboardView
from .screening import ListboardView as ScreeningListboardView
from .subject import DashboardView as SubjectDashboardView
from .subject import SubjectListboardView

__all__ = [
    "AeListboardView",
    "DeathReportListboardView",
    "ScreeningListboardView",
    "SubjectDashboardView",
    "SubjectListboardView",
]



from edc_consent.managers import ConsentObjectsByCdefManager, CurrentSiteByCdefManager
from edc_model.models import HistoricalRecords

from .subject_consent import SubjectConsent


class SubjectConsentV1(SubjectConsent):
    objects = ConsentObjectsByCdefManager()
    on_site = CurrentSiteByCdefManager()
    history = HistoricalRecords()

    class Meta:
        proxy = True
        verbose_name = "Consent V1"
        verbose_name_plural = "Consent V1"



from decimal import Decimal

from clinicedc_constants import MILLIMOLES_PER_LITER, NO, PENDING, YES
from clinicedc_utils import convert_units
from edc_crf.crf_form_validator import CrfFormValidator
from edc_form_validators import INVALID_ERROR
from edc_glucose.utils import validate_glucose_as_millimoles_per_liter

from meta_reports.models import GlucoseSummary

from .mixins import EndpointValidatorMixin, RepeatFbgDateValidatorMixin


class GlucoseFbgFormValidator(
    EndpointValidatorMixin, RepeatFbgDateValidatorMixin, CrfFormValidator
):
    def clean(self):
        self.required_if(YES, field="fasting", field_required="fasting_duration_str")
        self.required_if(NO, field="fbg_performed", field_required="fbg_not_performed_reason")
        self.required_if(YES, field="fbg_performed", field_required="fbg_datetime")
        if self.cleaned_data.get("fbg_datetime") and self.cleaned_data.get(
            "fbg_datetime"
        ) < self.cleaned_data.get("report_datetime"):
            self.raise_validation_error(
                {"fbg_datetime": "Invalid. Must be on or after report date above"},
                INVALID_ERROR,
            )
        self.applicable_if(
            YES, field="fbg_performed", field_applicable="fbg_diagnostic_device"
        )
        self.required_if(YES, field="fbg_performed", field_required="fbg_value")

        self.applicable_if(YES, field="fbg_performed", field_applicable="fbg_units")

        # endpoint
        self.applicable_if(
            YES,
            field="fbg_performed",
            field_applicable="endpoint_today",
            not_applicable_msg="This field is not applicable. Not performed",
        )
        self.validate_endpoint_fields(performed=self.cleaned_data.get("fbg_value") is not None)

        # repeat_fbg_date
        self.required_if(PENDING, field="endpoint_today", field_required="repeat_fbg_date")
        self.validate_repeat_fbg_date()

    @property
    def converted_fbg_value(self):
        if self.cleaned_data.get("fbg_value") is not None:
            return validate_glucose_as_millimoles_per_liter("fbg", self.cleaned_data)
        return None

    def is_endpoint(self):
        value = NO
        if self.converted_fbg_value and self.converted_fbg_value >= Decimal("7.0"):
            # is there a previous FBG>=7.0 in sequence or do you need to repeat?
            previous_obj = (
                GlucoseSummary.objects.filter(
                    subject_identifier=self.subject_identifier,
                    fbg_datetime__lt=self.cleaned_data.get("fbg_datetime"),
                )
                .order_by("fbg_datetime")
                .last()
            )
            previous_fbg_value = convert_units(
                label="fbg",
                value=float(previous_obj.fbg_value),
                units_from=previous_obj.fbg_units,
                units_to=MILLIMOLES_PER_LITER,
            )
            previous_ogtt_value = convert_units(
                label="ogtt",
                value=float(previous_obj.ogtt_value),
                units_from=previous_obj.ogtt_units,
                units_to=MILLIMOLES_PER_LITER,
            )

            if previous_obj and previous_fbg_value >= 7.0 and previous_ogtt_value <= 11.1:
                value = YES
            else:
                # you need to schedule a repeat
                value = PENDING
        return value



from edc_crf.crf_form_validator import CrfFormValidator
from edc_he.form_validators import SimpleFormValidatorMixin


class HealthEconomicsFormValidator(SimpleFormValidatorMixin, CrfFormValidator):
    def clean(self):
        self.clean_education()



from django.db import models
from edc_identifier.simple_identifier import SimpleUniqueIdentifier
from edc_model.models import BaseUuidModel
from edc_pharmacy.models import Lot

from .rx import Rx


class LabelIdentifier(SimpleUniqueIdentifier):
    random_string_length = 6
    identifier_type = "rx_label_reference"
    template = "{random_string}"


class RxLabel(BaseUuidModel):
    identifier_cls = LabelIdentifier

    rx = models.ForeignKey(Rx, on_delete=models.PROTECT)
    lot = models.ForeignKey(Lot, on_delete=models.PROTECT)
    label_identifier = models.CharField(max_length=15, unique=True)

    printed_datetime = models.DateTimeField(null=True)
    printed = models.BooleanField(default=False)
    scanned = models.BooleanField(default=False)
    scanned_datetime = models.DateTimeField(null=True)

    def __str__(self):
        return self.label_identifier

    def save(self, *args, **kwargs):
        """Label reference is always allocated."""
        if not self.id:
            self.label_identifier = self.identifier_cls().identifier
        super().save(*args, **kwargs)

    class Meta(BaseUuidModel.Meta):
        verbose_name = "Label"
        verbose_name_plural = "Labels"



from typing import Any

from django.apps import apps as django_apps
from django.core.checks import messages
from django.core.exceptions import ObjectDoesNotExist
from django.urls import reverse
from django.utils.html import format_html
from django.utils.safestring import mark_safe
from django.utils.translation import gettext_lazy as _
from edc_subject_dashboard.views import SubjectDashboardView

from meta_reports.models import Endpoints, GlucoseSummary


class DashboardView(SubjectDashboardView):
    consent_model = "meta_consent.subjectconsentv1"
    navbar_selected_item = "consented_subject"
    visit_model = "meta_subject.subjectvisit"
    history_button_label = _("Audit")

    def get_context_data(self, **kwargs) -> dict[str, Any]:
        """Add message if subject reaches DM Endpoint."""
        kwargs.update(subject_consent_v1_ext=self.subject_consent_v1_ext)
        try:
            Endpoints.objects.get(subject_identifier=self.subject_identifier)
        except ObjectDoesNotExist:
            pass
        else:
            url = reverse("meta_reports_admin:meta_reports_glucosesummary_changelist")
            url = mark_safe(f"{url}?q={self.subject_identifier}")  # noqa: S308
            message = format_html(
                '{text} <A href="{url}">{verbose_name}</A>',
                text=_("Subject has reached the protocol endpoint. See "),
                url=url,
                verbose_name=GlucoseSummary._meta.verbose_name,
            )
            self.message_user(message, level=messages.WARNING)
        return super().get_context_data(**kwargs)

    @property
    def subject_consent_v1_ext(self):
        model_cls = django_apps.get_model("meta_consent.subjectconsentv1ext")
        try:
            obj = model_cls.objects.get(subject_identifier=self.subject_identifier)
        except ObjectDoesNotExist:
            obj = None
        return obj



# Generated by Django 6.0 on 2025-04-22 19:14

import django_db_views.migration_functions
import django_db_views.operations
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0055_alter_glucosesummary_table"),
    ]

    operations = [
        django_db_views.operations.ViewRunPython(
            code=django_db_views.migration_functions.ForwardViewMigration(
                "select *, uuid() as id, now() as `created`, 'meta_reports.glucosesummaryview' as `report_model` from (SELECT v.subject_identifier, fbg_value, fbg_datetime, NULL AS `ogtt_value`, NULL AS `ogtt_datetime`, CASE WHEN fasting = 'fasting' THEN 'Yes' WHEN fasting = 'non_fasting' THEN 'No' ELSE fasting END AS `fasted`, fbg.site_id, v.visit_code, v.visit_code_sequence, v.appointment_id, eos.offstudy_datetime, fasting_duration_delta, 'meta_subject.glucosefbg' AS source FROM meta_subject_glucosefbg AS fbg LEFT JOIN meta_subject_subjectvisit AS v ON v.id = fbg.subject_visit_id LEFT JOIN meta_prn_endofstudy AS eos ON v.subject_identifier = eos.subject_identifier UNION SELECT v.subject_identifier, fbg_value, fbg_datetime, ogtt_value, ogtt_datetime, CASE WHEN fasting = 'fasting' THEN 'Yes' WHEN fasting = 'non_fasting' THEN 'No' ELSE fasting END AS `fasted`, fbg.site_id, v.visit_code, v.visit_code_sequence, v.appointment_id, eos.offstudy_datetime, fasting_duration_delta, 'meta_subject.glucose' AS source FROM meta_subject_glucose AS fbg LEFT JOIN meta_subject_subjectvisit AS v ON v.id = fbg.subject_visit_id LEFT JOIN meta_prn_endofstudy AS eos ON v.subject_identifier = eos.subject_identifier) as A ORDER BY subject_identifier, site_id",
                "meta_reports_glucosesummaryview",
                engine="django.db.backends.mysql",
            ),
            reverse_code=django_db_views.migration_functions.BackwardViewMigration(
                "select *, uuid() as id, now() as `created`, 'meta_reports.glucosesummaryview' as `report_model` from (SELECT v.subject_identifier, fbg_value, fbg_datetime, NULL AS `ogtt_value`, NULL AS `ogtt_datetime`, CASE WHEN fasting = 'fasting' THEN 'Yes' WHEN fasting = 'non_fasting' THEN 'No' ELSE fasting END AS `fasted`, fbg.site_id, v.visit_code, v.visit_code_sequence, v.appointment_id, eos.offstudy_datetime, fasting_duration_delta FROM meta_subject_glucosefbg AS fbg LEFT JOIN meta_subject_subjectvisit AS v ON v.id = fbg.subject_visit_id LEFT JOIN meta_prn_endofstudy AS eos ON v.subject_identifier = eos.subject_identifier UNION SELECT v.subject_identifier, fbg_value, fbg_datetime, ogtt_value, ogtt_datetime, CASE WHEN fasting = 'fasting' THEN 'Yes' WHEN fasting = 'non_fasting' THEN 'No' ELSE fasting END AS `fasted`, fbg.site_id, v.visit_code, v.visit_code_sequence, v.appointment_id, eos.offstudy_datetime, fasting_duration_delta FROM meta_subject_glucose AS fbg LEFT JOIN meta_subject_subjectvisit AS v ON v.id = fbg.subject_visit_id LEFT JOIN meta_prn_endofstudy AS eos ON v.subject_identifier = eos.subject_identifier) as A ORDER BY subject_identifier, site_id",
                "meta_reports_glucosesummaryview",
                engine="django.db.backends.mysql",
            ),
            atomic=False,
        ),
        django_db_views.operations.ViewRunPython(
            code=django_db_views.migration_functions.ForwardViewMigration(
                "select *, get_random_uuid() as id, now() as created, 'meta_reports.glucosesummaryview' as report_model from (SELECT v.subject_identifier, fbg_value, fbg_datetime, NULL AS \"ogtt_value\", NULL AS \"ogtt_datetime\", CASE WHEN fasting = 'fasting' THEN 'Yes' WHEN fasting = 'non_fasting' THEN 'No' ELSE fasting END AS \"fasted\", fbg.site_id, v.visit_code, v.visit_code_sequence, v.appointment_id, eos.offstudy_datetime, fasting_duration_delta, 'meta_subject.glucosefbg' AS source FROM meta_subject_glucosefbg AS fbg LEFT JOIN meta_subject_subjectvisit AS v ON v.id = fbg.subject_visit_id LEFT JOIN meta_prn_endofstudy AS eos ON v.subject_identifier = eos.subject_identifier UNION SELECT v.subject_identifier, fbg_value, fbg_datetime, ogtt_value, ogtt_datetime, CASE WHEN fasting = 'fasting' THEN 'Yes' WHEN fasting = 'non_fasting' THEN 'No' ELSE fasting END AS \"fasted\", fbg.site_id, v.visit_code, v.visit_code_sequence, v.appointment_id, eos.offstudy_datetime, fasting_duration_delta, 'meta_subject.glucose' AS source FROM meta_subject_glucose AS fbg LEFT JOIN meta_subject_subjectvisit AS v ON v.id = fbg.subject_visit_id LEFT JOIN meta_prn_endofstudy AS eos ON v.subject_identifier = eos.subject_identifier) as A ORDER BY subject_identifier, site_id",
                "meta_reports_glucosesummaryview",
                engine="django.db.backends.postgresql",
            ),
            reverse_code=django_db_views.migration_functions.BackwardViewMigration(
                "select *, get_random_uuid() as id, now() as created, 'meta_reports.glucosesummaryview' as report_model from (SELECT v.subject_identifier, fbg_value, fbg_datetime, NULL AS \"ogtt_value\", NULL AS \"ogtt_datetime\", CASE WHEN fasting = 'fasting' THEN 'Yes' WHEN fasting = 'non_fasting' THEN 'No' ELSE fasting END AS \"fasted\", fbg.site_id, v.visit_code, v.visit_code_sequence, v.appointment_id, eos.offstudy_datetime, fasting_duration_delta FROM meta_subject_glucosefbg AS fbg LEFT JOIN meta_subject_subjectvisit AS v ON v.id = fbg.subject_visit_id LEFT JOIN meta_prn_endofstudy AS eos ON v.subject_identifier = eos.subject_identifier UNION SELECT v.subject_identifier, fbg_value, fbg_datetime, ogtt_value, ogtt_datetime, CASE WHEN fasting = 'fasting' THEN 'Yes' WHEN fasting = 'non_fasting' THEN 'No' ELSE fasting END AS \"fasted\", fbg.site_id, v.visit_code, v.visit_code_sequence, v.appointment_id, eos.offstudy_datetime, fasting_duration_delta FROM meta_subject_glucose AS fbg LEFT JOIN meta_subject_subjectvisit AS v ON v.id = fbg.subject_visit_id LEFT JOIN meta_prn_endofstudy AS eos ON v.subject_identifier = eos.subject_identifier) as A ORDER BY subject_identifier, site_id",
                "meta_reports_glucosesummaryview",
                engine="django.db.backends.postgresql",
            ),
            atomic=False,
        ),
        django_db_views.operations.ViewRunPython(
            code=django_db_views.migration_functions.ForwardViewMigration(
                "select *, uuid() as id, datetime() as created, 'meta_reports.glucosesummaryview' as report_model from (SELECT v.subject_identifier, fbg_value, fbg_datetime, NULL AS \"ogtt_value\", NULL AS \"ogtt_datetime\", CASE WHEN fasting = 'fasting' THEN 'Yes' WHEN fasting = 'non_fasting' THEN 'No' ELSE fasting END AS \"fasted\", fbg.site_id, v.visit_code, v.visit_code_sequence, v.appointment_id, eos.offstudy_datetime, fasting_duration_delta, 'meta_subject.glucosefbg' AS source FROM meta_subject_glucosefbg AS fbg LEFT JOIN meta_subject_subjectvisit AS v ON v.id = fbg.subject_visit_id LEFT JOIN meta_prn_endofstudy AS eos ON v.subject_identifier = eos.subject_identifier UNION SELECT v.subject_identifier, fbg_value, fbg_datetime, ogtt_value, ogtt_datetime, CASE WHEN fasting = 'fasting' THEN 'Yes' WHEN fasting = 'non_fasting' THEN 'No' ELSE fasting END AS \"fasted\", fbg.site_id, v.visit_code, v.visit_code_sequence, v.appointment_id, eos.offstudy_datetime, fasting_duration_delta, 'meta_subject.glucose' AS source FROM meta_subject_glucose AS fbg LEFT JOIN meta_subject_subjectvisit AS v ON v.id = fbg.subject_visit_id LEFT JOIN meta_prn_endofstudy AS eos ON v.subject_identifier = eos.subject_identifier) as A ORDER BY subject_identifier, site_id",
                "meta_reports_glucosesummaryview",
                engine="django.db.backends.sqlite3",
            ),
            reverse_code=django_db_views.migration_functions.BackwardViewMigration(
                "select *, uuid() as id, datetime() as created, 'meta_reports.glucosesummaryview' as report_model from (SELECT v.subject_identifier, fbg_value, fbg_datetime, NULL AS \"ogtt_value\", NULL AS \"ogtt_datetime\", CASE WHEN fasting = 'fasting' THEN 'Yes' WHEN fasting = 'non_fasting' THEN 'No' ELSE fasting END AS \"fasted\", fbg.site_id, v.visit_code, v.visit_code_sequence, v.appointment_id, eos.offstudy_datetime, fasting_duration_delta FROM meta_subject_glucosefbg AS fbg LEFT JOIN meta_subject_subjectvisit AS v ON v.id = fbg.subject_visit_id LEFT JOIN meta_prn_endofstudy AS eos ON v.subject_identifier = eos.subject_identifier UNION SELECT v.subject_identifier, fbg_value, fbg_datetime, ogtt_value, ogtt_datetime, CASE WHEN fasting = 'fasting' THEN 'Yes' WHEN fasting = 'non_fasting' THEN 'No' ELSE fasting END AS \"fasted\", fbg.site_id, v.visit_code, v.visit_code_sequence, v.appointment_id, eos.offstudy_datetime, fasting_duration_delta FROM meta_subject_glucose AS fbg LEFT JOIN meta_subject_subjectvisit AS v ON v.id = fbg.subject_visit_id LEFT JOIN meta_prn_endofstudy AS eos ON v.subject_identifier = eos.subject_identifier) as A ORDER BY subject_identifier, site_id",
                "meta_reports_glucosesummaryview",
                engine="django.db.backends.sqlite3",
            ),
            atomic=False,
        ),
    ]



from django import forms
from edc_consent.modelform_mixins import RequiresConsentModelFormMixin
from edc_form_validators import FormValidatorMixin
from edc_offstudy.modelform_mixins import OffstudyNonCrfModelFormMixin
from edc_visit_tracking.form_validators import VisitFormValidator
from edc_visit_tracking.modelform_mixins import VisitTrackingModelFormMixin

from meta_prn.models import OffStudyMedication
from meta_visit_schedule.constants import SCHEDULE_DM_REFERRAL

from ..models import SubjectVisit


class SubjectVisitFormValidator(VisitFormValidator):
    validate_missed_visit_reason = False


class SubjectVisitForm(
    RequiresConsentModelFormMixin,
    VisitTrackingModelFormMixin,
    OffstudyNonCrfModelFormMixin,
    FormValidatorMixin,
    forms.ModelForm,
):
    form_validator_cls = SubjectVisitFormValidator

    def clean(self):
        cleaned_data = super().clean()
        if (
            self.cleaned_data.get("appointment").schedule_name == SCHEDULE_DM_REFERRAL
            and not OffStudyMedication.objects.filter(
                subject_identifier=self.subject_identifier
            ).exists()
        ):
            raise forms.ValidationError(
                f"Submit form `{OffStudyMedication._meta.verbose_name}` first."
            )
        return cleaned_data

    class Meta:
        model = SubjectVisit
        fields = "__all__"



# Generated by Django 3.2.11 on 2022-03-12 00:39

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_screening", "0036_auto_20220304_2307"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="repeat_fbg_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If repeated, must be at least 3 days after the first FBG measures",
                max_length=15,
                verbose_name="Was the FBG repeated?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="repeat_ogtt_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If repeated, must be at least 3 days after the first OGTT measures",
                max_length=15,
                verbose_name="Was the OGTT repeated?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="repeat_fbg_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If repeated, must be at least 3 days after the first FBG measures",
                max_length=15,
                verbose_name="Was the FBG repeated?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="repeat_ogtt_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If repeated, must be at least 3 days after the first OGTT measures",
                max_length=15,
                verbose_name="Was the OGTT repeated?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="repeat_fbg_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If repeated, must be at least 3 days after the first FBG measures",
                max_length=15,
                verbose_name="Was the FBG repeated?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="repeat_ogtt_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If repeated, must be at least 3 days after the first OGTT measures",
                max_length=15,
                verbose_name="Was the OGTT repeated?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="repeat_fbg_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If repeated, must be at least 3 days after the first FBG measures",
                max_length=15,
                verbose_name="Was the FBG repeated?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="repeat_ogtt_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If repeated, must be at least 3 days after the first OGTT measures",
                max_length=15,
                verbose_name="Was the OGTT repeated?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="repeat_fbg_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If repeated, must be at least 3 days after the first FBG measures",
                max_length=15,
                verbose_name="Was the FBG repeated?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="repeat_ogtt_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If repeated, must be at least 3 days after the first OGTT measures",
                max_length=15,
                verbose_name="Was the OGTT repeated?",
            ),
        ),
    ]



from edc_visit_schedule.visit import Crf, CrfCollection

crfs_prn = CrfCollection(
    Crf(show_order=105, model="meta_subject.bloodresultsfbc"),
    Crf(show_order=156, model="meta_subject.glucose"),
    Crf(show_order=225, model="meta_subject.glucosefbg"),
    Crf(show_order=235, model="meta_subject.bloodresultshba1c"),
    Crf(show_order=245, model="meta_subject.bloodresultsrft"),
    Crf(show_order=255, model="meta_subject.bloodresultslft"),
    Crf(show_order=265, model="meta_subject.bloodresultslipids"),
    Crf(show_order=268, model="meta_subject.bloodresultsins"),
    Crf(show_order=321, model="meta_subject.hivexitreview"),
    Crf(show_order=461, model="meta_subject.eq5d3l"),
    Crf(show_order=466, model="meta_subject.sf12"),
    Crf(show_order=471, model="meta_subject.mnsi"),
    Crf(show_order=275, model="meta_subject.hepatitistest"),
    Crf(show_order=285, model="meta_subject.malariatest"),
    Crf(show_order=295, model="meta_subject.urinedipsticktest"),
    Crf(show_order=365, model="meta_subject.concomitantmedication"),
    Crf(show_order=385, model="meta_subject.urinepregnancy"),
    Crf(show_order=505, model="meta_subject.pregnancyupdate"),
    Crf(show_order=515, model="meta_subject.egfrdropnotification"),
    name="prn",
)

crfs_unscheduled = CrfCollection(
    Crf(show_order=106, model="meta_subject.followupvitals"),
    Crf(show_order=206, model="meta_subject.followupexamination"),
    Crf(show_order=306, model="meta_subject.medicationadherence"),
    Crf(show_order=406, model="meta_subject.glucosefbg"),
    name="unscheduled",
)

crfs_missed = CrfCollection(
    Crf(show_order=107, model="meta_subject.subjectvisitmissed"),
    name="missed",
)
crfs_d1 = CrfCollection(
    Crf(show_order=100, model="meta_subject.physicalexam"),
    Crf(show_order=120, model="meta_subject.patienthistory"),
    Crf(show_order=130, model="meta_subject.otherarvregimens"),
    Crf(show_order=155, model="meta_subject.glucose", required=False),
    Crf(show_order=210, model="meta_subject.bloodresultsins"),
    Crf(show_order=220, model="meta_subject.bloodresultshba1c"),
    Crf(show_order=230, model="meta_subject.bloodresultsrft"),
    Crf(show_order=240, model="meta_subject.bloodresultslft"),
    Crf(show_order=250, model="meta_subject.bloodresultsfbc"),
    Crf(show_order=260, model="meta_subject.bloodresultslipids"),
    Crf(show_order=360, model="meta_subject.malariatest"),
    Crf(show_order=370, model="meta_subject.urinedipsticktest"),
    Crf(show_order=400, model="meta_subject.studymedication"),
    Crf(show_order=600, model="meta_subject.nextappointment", required=False),
    name="day1",
)

crfs_w2 = CrfCollection(
    Crf(show_order=100, model="meta_subject.followupvitals"),
    Crf(show_order=150, model="meta_subject.followupexamination"),
    Crf(show_order=155, model="meta_subject.glucose", required=False),
    Crf(show_order=200, model="meta_subject.glucosefbg"),
    Crf(show_order=300, model="meta_subject.studymedication"),
    Crf(show_order=310, model="meta_subject.medicationadherence"),
    Crf(show_order=460, model="meta_subject.eq5d3l"),
    Crf(show_order=465, model="meta_subject.sf12"),
    Crf(show_order=480, model="meta_subject.healtheconomicssimple"),
    Crf(show_order=600, model="meta_subject.nextappointment", required=False),
    name="week2",
)

crfs_1m = CrfCollection(
    Crf(show_order=100, model="meta_subject.followupvitals"),
    Crf(show_order=150, model="meta_subject.followupexamination"),
    Crf(show_order=155, model="meta_subject.glucose", required=False),
    Crf(show_order=200, model="meta_subject.glucosefbg"),
    Crf(show_order=300, model="meta_subject.studymedication"),
    Crf(show_order=310, model="meta_subject.medicationadherence"),
    Crf(show_order=460, model="meta_subject.eq5d3l", required=False),
    Crf(show_order=465, model="meta_subject.sf12", required=False),
    Crf(show_order=470, model="meta_subject.mnsi"),
    Crf(show_order=480, model="meta_subject.healtheconomicssimple", required=False),
    Crf(show_order=600, model="meta_subject.nextappointment", required=False),
    name="1m",
)

crfs_3m = CrfCollection(
    Crf(show_order=100, model="meta_subject.followupvitals"),
    Crf(show_order=150, model="meta_subject.followupexamination"),
    Crf(show_order=155, model="meta_subject.glucose", required=False),
    Crf(show_order=200, model="meta_subject.glucosefbg"),
    Crf(show_order=210, model="meta_subject.bloodresultsrft"),
    Crf(show_order=220, model="meta_subject.bloodresultslft"),
    Crf(show_order=300, model="meta_subject.studymedication"),
    Crf(show_order=310, model="meta_subject.medicationadherence"),
    Crf(show_order=460, model="meta_subject.eq5d3l", required=False),
    Crf(show_order=465, model="meta_subject.sf12", required=False),
    Crf(show_order=470, model="meta_subject.mnsi", required=False),
    Crf(show_order=500, model="meta_subject.healtheconomicsupdate"),
    Crf(show_order=600, model="meta_subject.nextappointment", required=False),
    name="3m",
)

crfs_6m = CrfCollection(
    Crf(show_order=100, model="meta_subject.followupvitals"),
    Crf(show_order=150, model="meta_subject.followupexamination"),
    Crf(show_order=200, model="meta_subject.glucose", required=False),
    Crf(show_order=205, model="meta_subject.glucosefbg"),
    Crf(show_order=210, model="meta_subject.bloodresultsrft"),
    Crf(show_order=220, model="meta_subject.bloodresultslft"),
    Crf(show_order=230, model="meta_subject.bloodresultsfbc"),
    Crf(show_order=300, model="meta_subject.studymedication"),
    Crf(show_order=310, model="meta_subject.medicationadherence"),
    Crf(show_order=460, model="meta_subject.eq5d3l", required=False),
    Crf(show_order=465, model="meta_subject.sf12", required=False),
    Crf(show_order=470, model="meta_subject.mnsi", required=False),
    Crf(show_order=500, model="meta_subject.healtheconomicsupdate", required=False),
    Crf(show_order=600, model="meta_subject.nextappointment", required=False),
    name="6m",
)

crfs_9m = CrfCollection(
    Crf(show_order=100, model="meta_subject.followupvitals"),
    Crf(show_order=150, model="meta_subject.followupexamination"),
    Crf(show_order=155, model="meta_subject.glucose", required=False),
    Crf(show_order=200, model="meta_subject.glucosefbg"),
    Crf(show_order=300, model="meta_subject.studymedication"),
    Crf(show_order=310, model="meta_subject.medicationadherence"),
    Crf(show_order=460, model="meta_subject.eq5d3l", required=False),
    Crf(show_order=465, model="meta_subject.sf12", required=False),
    Crf(show_order=500, model="meta_subject.healtheconomicsupdate", required=False),
    Crf(show_order=600, model="meta_subject.nextappointment", required=False),
    name="9m",
)

crfs_12m = CrfCollection(
    Crf(show_order=100, model="meta_subject.followupvitals"),
    Crf(show_order=150, model="meta_subject.followupexamination"),
    Crf(show_order=155, model="meta_subject.glucose"),
    Crf(show_order=210, model="meta_subject.bloodresultshba1c"),
    Crf(show_order=220, model="meta_subject.bloodresultsrft"),
    Crf(show_order=230, model="meta_subject.bloodresultslft"),
    Crf(show_order=240, model="meta_subject.bloodresultsfbc"),
    Crf(show_order=250, model="meta_subject.bloodresultslipids"),
    Crf(show_order=300, model="meta_subject.studymedication"),
    Crf(show_order=310, model="meta_subject.medicationadherence"),
    Crf(show_order=320, model="meta_subject.hivexitreview", required=False),
    Crf(show_order=460, model="meta_subject.eq5d3l", required=False),
    Crf(show_order=465, model="meta_subject.sf12", required=False),
    Crf(show_order=500, model="meta_subject.healtheconomicsupdate", required=False),
    Crf(show_order=600, model="meta_subject.nextappointment", required=False),
    name="12m",
)

crfs_15m = CrfCollection(
    Crf(show_order=100, model="meta_subject.followupvitals"),
    Crf(show_order=150, model="meta_subject.followupexamination"),
    Crf(show_order=155, model="meta_subject.glucose", required=False),
    Crf(show_order=200, model="meta_subject.glucosefbg"),
    Crf(show_order=300, model="meta_subject.studymedication"),
    Crf(show_order=310, model="meta_subject.medicationadherence"),
    Crf(show_order=320, model="meta_subject.hivexitreview", required=False),
    Crf(show_order=460, model="meta_subject.eq5d3l", required=False),
    Crf(show_order=465, model="meta_subject.sf12", required=False),
    Crf(show_order=500, model="meta_subject.healtheconomicsupdate", required=False),
    Crf(show_order=600, model="meta_subject.nextappointment", required=False),
    name="15m",
)

crfs_18m = CrfCollection(
    Crf(show_order=100, model="meta_subject.followupvitals"),
    Crf(show_order=150, model="meta_subject.followupexamination"),
    Crf(show_order=155, model="meta_subject.glucose", required=False),
    Crf(show_order=205, model="meta_subject.glucosefbg"),
    Crf(show_order=220, model="meta_subject.bloodresultsfbc"),
    Crf(show_order=300, model="meta_subject.studymedication"),
    Crf(show_order=310, model="meta_subject.medicationadherence"),
    Crf(show_order=320, model="meta_subject.hivexitreview", required=False),
    Crf(show_order=460, model="meta_subject.eq5d3l", required=False),
    Crf(show_order=465, model="meta_subject.sf12", required=False),
    Crf(show_order=500, model="meta_subject.healtheconomicsupdate", required=False),
    Crf(show_order=600, model="meta_subject.nextappointment", required=False),
    name="18m",
)

crfs_21m = CrfCollection(
    Crf(show_order=100, model="meta_subject.followupvitals"),
    Crf(show_order=150, model="meta_subject.followupexamination"),
    Crf(show_order=155, model="meta_subject.glucose", required=False),
    Crf(show_order=200, model="meta_subject.glucosefbg"),
    Crf(show_order=300, model="meta_subject.studymedication"),
    Crf(show_order=310, model="meta_subject.medicationadherence"),
    Crf(show_order=320, model="meta_subject.hivexitreview", required=False),
    Crf(show_order=460, model="meta_subject.eq5d3l", required=False),
    Crf(show_order=465, model="meta_subject.sf12", required=False),
    Crf(show_order=500, model="meta_subject.healtheconomicsupdate", required=False),
    Crf(show_order=600, model="meta_subject.nextappointment", required=False),
    name="21m",
)

crfs_24m = CrfCollection(
    Crf(show_order=100, model="meta_subject.followupvitals"),
    Crf(show_order=150, model="meta_subject.followupexamination"),
    Crf(show_order=200, model="meta_subject.glucose"),
    Crf(show_order=210, model="meta_subject.bloodresultshba1c"),
    Crf(show_order=220, model="meta_subject.bloodresultsrft"),
    Crf(show_order=230, model="meta_subject.bloodresultslft"),
    Crf(show_order=240, model="meta_subject.bloodresultsfbc"),
    # Crf(show_order=250, model="meta_subject.bloodresultslipids"),
    Crf(show_order=300, model="meta_subject.studymedication"),
    Crf(show_order=310, model="meta_subject.medicationadherence"),
    Crf(show_order=320, model="meta_subject.hivexitreview", required=False),
    Crf(show_order=460, model="meta_subject.eq5d3l", required=False),
    Crf(show_order=465, model="meta_subject.sf12", required=False),
    Crf(show_order=470, model="meta_subject.mnsi"),
    Crf(show_order=500, model="meta_subject.healtheconomicsupdate", required=False),
    Crf(show_order=600, model="meta_subject.nextappointment", required=False),
    name="24m",
)

crfs_27m = CrfCollection(
    Crf(show_order=100, model="meta_subject.followupvitals"),
    Crf(show_order=150, model="meta_subject.followupexamination"),
    Crf(show_order=155, model="meta_subject.glucose", required=False),
    Crf(show_order=300, model="meta_subject.studymedication"),
    Crf(show_order=310, model="meta_subject.medicationadherence"),
    Crf(show_order=320, model="meta_subject.hivexitreview", required=False),
    Crf(show_order=460, model="meta_subject.eq5d3l", required=False),
    Crf(show_order=465, model="meta_subject.sf12", required=False),
    Crf(show_order=470, model="meta_subject.mnsi", required=False),
    Crf(show_order=500, model="meta_subject.healtheconomicsupdate", required=False),
    Crf(show_order=600, model="meta_subject.nextappointment", required=False),
    name="27m",
)

crfs_30m = CrfCollection(
    Crf(show_order=100, model="meta_subject.followupvitals"),
    Crf(show_order=150, model="meta_subject.followupexamination"),
    Crf(show_order=155, model="meta_subject.glucose", required=False),
    Crf(show_order=205, model="meta_subject.glucosefbg"),
    Crf(show_order=300, model="meta_subject.studymedication"),
    Crf(show_order=310, model="meta_subject.medicationadherence"),
    Crf(show_order=320, model="meta_subject.hivexitreview", required=False),
    Crf(show_order=460, model="meta_subject.eq5d3l", required=False),
    Crf(show_order=465, model="meta_subject.sf12", required=False),
    Crf(show_order=470, model="meta_subject.mnsi", required=False),
    Crf(show_order=500, model="meta_subject.healtheconomicsupdate", required=False),
    Crf(show_order=600, model="meta_subject.nextappointment", required=False),
    name="30m",
)

crfs_33m = CrfCollection(
    Crf(show_order=100, model="meta_subject.followupvitals"),
    Crf(show_order=150, model="meta_subject.followupexamination"),
    Crf(show_order=155, model="meta_subject.glucose", required=False),
    Crf(show_order=300, model="meta_subject.studymedication"),
    Crf(show_order=310, model="meta_subject.medicationadherence"),
    Crf(show_order=320, model="meta_subject.hivexitreview", required=False),
    Crf(show_order=460, model="meta_subject.eq5d3l", required=False),
    Crf(show_order=465, model="meta_subject.sf12", required=False),
    Crf(show_order=470, model="meta_subject.mnsi", required=False),
    Crf(show_order=500, model="meta_subject.healtheconomicsupdate", required=False),
    Crf(show_order=600, model="meta_subject.nextappointment", required=False),
    name="33m",
)

crfs_36m = CrfCollection(
    Crf(show_order=100, model="meta_subject.followupvitals"),
    Crf(show_order=150, model="meta_subject.followupexamination"),
    Crf(show_order=200, model="meta_subject.glucose"),
    Crf(show_order=210, model="meta_subject.bloodresultshba1c"),
    Crf(show_order=220, model="meta_subject.bloodresultsrft"),
    Crf(show_order=230, model="meta_subject.bloodresultslft"),
    Crf(show_order=240, model="meta_subject.bloodresultsfbc"),
    Crf(show_order=250, model="meta_subject.bloodresultslipids"),
    Crf(show_order=300, model="meta_subject.studymedication"),
    Crf(show_order=310, model="meta_subject.medicationadherence"),
    Crf(show_order=320, model="meta_subject.hivexitreview", required=False),
    Crf(show_order=460, model="meta_subject.eq5d3l"),
    Crf(show_order=465, model="meta_subject.sf12"),
    Crf(show_order=470, model="meta_subject.mnsi"),
    Crf(show_order=500, model="meta_subject.healtheconomicsupdate", required=False),
    Crf(show_order=600, model="meta_subject.nextappointment", required=False),
    name="36m",
)

crfs_39m = CrfCollection(
    Crf(show_order=100, model="meta_subject.followupvitals"),
    Crf(show_order=150, model="meta_subject.followupexamination"),
    Crf(show_order=155, model="meta_subject.glucose", required=False),
    Crf(show_order=300, model="meta_subject.studymedication"),
    Crf(show_order=310, model="meta_subject.medicationadherence"),
    Crf(show_order=320, model="meta_subject.hivexitreview", required=False),
    Crf(show_order=460, model="meta_subject.eq5d3l", required=False),
    Crf(show_order=465, model="meta_subject.sf12", required=False),
    Crf(show_order=470, model="meta_subject.mnsi", required=False),
    Crf(show_order=500, model="meta_subject.healtheconomicsupdate", required=False),
    Crf(show_order=600, model="meta_subject.nextappointment", required=False),
    name="39m",
)

crfs_42m = CrfCollection(
    Crf(show_order=100, model="meta_subject.followupvitals"),
    Crf(show_order=150, model="meta_subject.followupexamination"),
    Crf(show_order=155, model="meta_subject.glucose", required=False),
    Crf(show_order=200, model="meta_subject.glucosefbg"),
    Crf(show_order=300, model="meta_subject.studymedication"),
    Crf(show_order=310, model="meta_subject.medicationadherence"),
    Crf(show_order=320, model="meta_subject.hivexitreview", required=False),
    Crf(show_order=460, model="meta_subject.eq5d3l", required=False),
    Crf(show_order=465, model="meta_subject.sf12", required=False),
    Crf(show_order=470, model="meta_subject.mnsi", required=False),
    Crf(show_order=500, model="meta_subject.healtheconomicsupdate", required=False),
    Crf(show_order=600, model="meta_subject.nextappointment", required=False),
    name="42m",
)

crfs_45m = CrfCollection(
    Crf(show_order=100, model="meta_subject.followupvitals"),
    Crf(show_order=150, model="meta_subject.followupexamination"),
    Crf(show_order=155, model="meta_subject.glucose", required=False),
    Crf(show_order=300, model="meta_subject.studymedication"),
    Crf(show_order=310, model="meta_subject.medicationadherence"),
    Crf(show_order=320, model="meta_subject.hivexitreview", required=False),
    Crf(show_order=460, model="meta_subject.eq5d3l", required=False),
    Crf(show_order=465, model="meta_subject.sf12", required=False),
    Crf(show_order=470, model="meta_subject.mnsi", required=False),
    Crf(show_order=500, model="meta_subject.healtheconomicsupdate", required=False),
    Crf(show_order=600, model="meta_subject.nextappointment", required=False),
    name="45m",
)

crfs_48m = CrfCollection(
    Crf(show_order=100, model="meta_subject.followupvitals"),
    Crf(show_order=150, model="meta_subject.followupexamination"),
    Crf(show_order=200, model="meta_subject.glucose"),
    Crf(show_order=210, model="meta_subject.bloodresultshba1c"),
    Crf(show_order=220, model="meta_subject.bloodresultsrft"),
    Crf(show_order=230, model="meta_subject.bloodresultslft"),
    Crf(show_order=240, model="meta_subject.bloodresultsfbc"),
    Crf(show_order=250, model="meta_subject.bloodresultslipids"),
    Crf(show_order=300, model="meta_subject.studymedication"),
    Crf(show_order=310, model="meta_subject.medicationadherence"),
    Crf(show_order=320, model="meta_subject.hivexitreview"),
    Crf(show_order=460, model="meta_subject.eq5d3l"),
    Crf(show_order=465, model="meta_subject.sf12"),
    Crf(show_order=470, model="meta_subject.mnsi"),
    Crf(show_order=500, model="meta_subject.healtheconomicsupdate", required=False),
    Crf(show_order=600, model="meta_subject.nextappointment", required=False),
    name="48m",
)

crfs_endline = CrfCollection(Crf(show_order=200, model="meta_subject.glucose"))



# Generated by Django 4.2.11 on 2024-05-15 23:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0197_glucosefbg_fasting_duration_estimated_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="glucosefbg",
            name="fasting_duration_estimated",
            field=models.CharField(
                default="No",
                editable=False,
                help_text="Set to YES for existing values before duration question was added to the form, otherwise NO",
                max_length=15,
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucosefbg",
            name="fasting_duration_estimated",
            field=models.CharField(
                default="No",
                editable=False,
                help_text="Set to YES for existing values before duration question was added to the form, otherwise NO",
                max_length=15,
            ),
        ),
    ]



# Generated by Django 5.0.7 on 2024-08-13 12:16

import django_db_views.migration_functions
import django_db_views.operations
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0011_auto_20240813_0156"),
    ]

    operations = [
        django_db_views.operations.ViewRunPython(
            code=django_db_views.migration_functions.ForwardViewMigration(
                "select *, uuid() as id, now() as created, 'meta_reports.unattendedthreeinrow' as `report_model` from (\n        select subject_identifier, site_id, appt_datetime, `first_value`, `second_value`, `third_value`,\n            datediff(third_date, first_date) as `interval_days`,\n            datediff(now(), first_date) as `from_now_days`\n        from (\n            select subject_identifier, site_id, appt_datetime,\n            FIRST_VALUE(visit_code) OVER w as `first_value`,\n            NTH_VALUE(visit_code, 2) OVER w as `second_value`,\n            NTH_VALUE(visit_code, 3) OVER w as `third_value`,\n            FIRST_VALUE(appt_datetime) OVER w as `first_date`,\n            NTH_VALUE(appt_datetime, 3) OVER w as `third_date`\n            from edc_appointment_appointment where visit_code_sequence=0 and appt_status='New'\n            and appt_datetime <= now()\n            WINDOW w as (PARTITION BY subject_identifier order by appt_datetime ROWS UNBOUNDED PRECEDING)\n        ) as A\n    where `second_value` is not null and `third_value` is not null\n    ) as B\n    order by site_id, from_now_days desc",
                "unattended_three_in_row_view",
                engine="django.db.backends.mysql",
            ),
            reverse_code=django_db_views.migration_functions.BackwardViewMigration(
                "", "unattended_three_in_row_view", engine="django.db.backends.mysql"
            ),
            atomic=False,
        ),
        django_db_views.operations.ViewRunPython(
            code=django_db_views.migration_functions.ForwardViewMigration(
                "select *, gen_random_uuid() as id, now() as created, \n    'meta_reports.unattendedthreeinrow' as report_model \n    from (\n    select subject_identifier, site_id, appt_datetime, first_value, second_value, third_value,\n    EXTRACT(DAY FROM third_date - first_date) as interval_days,\n    EXTRACT(DAY FROM now() - first_date) as from_now_days \n    from (\n    select subject_identifier,site_id,appt_datetime,\n    FIRST_VALUE(visit_code) OVER w as first_value,\n    NTH_VALUE(visit_code, 2) OVER w as second_value,\n    NTH_VALUE(visit_code, 3) OVER w as third_value,\n    FIRST_VALUE(appt_datetime) OVER w as first_date,\n    NTH_VALUE(appt_datetime, 3) OVER w as third_date\n    from edc_appointment_appointment where visit_code_sequence=0 and appt_status='New'\n    and appt_datetime <= now()\n    WINDOW w as (PARTITION BY subject_identifier order by appt_datetime ROWS UNBOUNDED PRECEDING)\n    ) as A\n    where second_value is not null and third_value is not null\n    ) as B\n    order by site_id, from_now_days desc",
                "unattended_three_in_row_view",
                engine="django.db.backends.postgresql",
            ),
            reverse_code=django_db_views.migration_functions.BackwardViewMigration(
                "", "unattended_three_in_row_view", engine="django.db.backends.postgresql"
            ),
            atomic=False,
        ),
        django_db_views.operations.ViewRunPython(
            code=django_db_views.migration_functions.ForwardViewMigration(
                "SELECT *, lower(\n    hex(randomblob(4)) || '-' || hex(randomblob(2)) || '-' || '4' ||\n    substr(hex( randomblob(2)), 2) || '-' ||\n    substr('AB89', 1 + (abs(random()) % 4) , 1)  ||\n    substr(hex(randomblob(2)), 2) || '-' ||\n    hex(randomblob(6))\n  ) as id, datetime() as created,'meta_reports.unattendedthreeinrow' as report_model from (\n        select subject_identifier, site_id, appt_datetime, first_value, second_value, third_value,\n            CAST(JulianDay(third_date) - JulianDay(first_date) AS Integer) as interval_days,\n            CAST(JulianDay(datetime()) - JulianDay(first_date) AS Integer) as from_now_days\n        from (\n            select subject_identifier, site_id, appt_datetime,\n            FIRST_VALUE(visit_code) OVER w as first_value,\n            NTH_VALUE(visit_code, 2) OVER w as second_value,\n            NTH_VALUE(visit_code, 3) OVER w as third_value,\n            FIRST_VALUE(appt_datetime) OVER w as first_date,\n            NTH_VALUE(appt_datetime, 3) OVER w as third_date\n            from edc_appointment_appointment where visit_code_sequence=0 and appt_status='New'\n            and appt_datetime <= datetime()\n            WINDOW w as (PARTITION BY subject_identifier order by appt_datetime ROWS UNBOUNDED PRECEDING)\n        ) as A\n    where second_value is not null and third_value is not null\n    ) as B\n    order by site_id, from_now_days desc",
                "unattended_three_in_row_view",
                engine="django.db.backends.sqlite3",
            ),
            reverse_code=django_db_views.migration_functions.BackwardViewMigration(
                "", "unattended_three_in_row_view", engine="django.db.backends.sqlite3"
            ),
            atomic=False,
        ),
    ]



# Generated by Django 3.0.6 on 2020-05-28 12:55

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0042_auto_20200528_0252"),
    ]

    operations = [
        migrations.AddField(
            model_name="followup",
            name="symptoms_g3_detail",
            field=models.TextField(
                blank=True,
                null=True,
                verbose_name="Please provide details on any of the Grade 3 symptoms above.",
            ),
        ),
        migrations.AddField(
            model_name="followup",
            name="symptoms_g4_detail",
            field=models.TextField(
                blank=True,
                null=True,
                verbose_name="Please provide details on any of the Grade 4 symptoms above.",
            ),
        ),
        migrations.AddField(
            model_name="historicalfollowup",
            name="symptoms_g3_detail",
            field=models.TextField(
                blank=True,
                null=True,
                verbose_name="Please provide details on any of the Grade 3 symptoms above.",
            ),
        ),
        migrations.AddField(
            model_name="historicalfollowup",
            name="symptoms_g4_detail",
            field=models.TextField(
                blank=True,
                null=True,
                verbose_name="Please provide details on any of the Grade 4 symptoms above.",
            ),
        ),
    ]



# Generated by Django 3.2.4 on 2021-07-10 16:29

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_screening", "0023_auto_20210702_0533"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="staying_nearby_12",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient planning to remain in the catchment area for at least 12 months",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="staying_nearby_12",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient planning to remain in the catchment area for at least 12 months",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="staying_nearby_12",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient planning to remain in the catchment area for at least 12 months",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="staying_nearby_12",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient planning to remain in the catchment area for at least 12 months",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="staying_nearby_12",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient planning to remain in the catchment area for at least 12 months",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="staying_nearby",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient planning to remain in the catchment area for at least 6 months",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="staying_nearby",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient planning to remain in the catchment area for at least 6 months",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="staying_nearby",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient planning to remain in the catchment area for at least 6 months",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="staying_nearby",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient planning to remain in the catchment area for at least 6 months",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="staying_nearby",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient planning to remain in the catchment area for at least 6 months",
            ),
        ),
    ]



# Generated by Django 3.2.11 on 2022-04-14 21:43
from django.core.exceptions import ObjectDoesNotExist
from django.db import migrations
from django.db.migrations import RunPython
from edc_consent.utils import get_consent_model_name
from edc_pharmacy.prescribe import create_prescription

from meta_edc.meta_version import get_meta_version
from meta_pharmacy.constants import METFORMIN


def func(apps, schema_editor):
    try:
        medication = apps.get_model("edc_pharmacy.medication")._default_manager.get(
            name=METFORMIN
        )
    except ObjectDoesNotExist:
        pass
    else:
        site_model_cls = apps.get_model("sites.site")
        subject_identifiers = [
            tpl[0]
            for tpl in apps.get_model("edc_pharmacy.rx")._default_manager.values_list(
                "subject_identifier"
            )
        ]
        for subject_consent in apps.get_model(
            get_consent_model_name()
        )._default_manager.exclude(subject_identifier__in=subject_identifiers):
            site = site_model_cls.objects.get(id=subject_consent.site.id)
            create_prescription(
                subject_identifier=subject_consent.subject_identifier,
                report_datetime=subject_consent.consent_datetime,
                randomizer_name=get_meta_version(),
                medication_names=[METFORMIN],
                site_id=site.id,
            )
        for obj in apps.get_model("edc_pharmacy.rx")._default_manager.all():
            obj.medications.clear()
            obj.medications.add(medication)


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0106_auto_20220414_1741"),
    ]

    operations = [RunPython(func)]



from django.contrib import admin
from edc_consent.modeladmin_mixins import ModelAdminConsentMixin
from edc_model_admin.dashboard import ModelAdminSubjectDashboardMixin
from edc_model_admin.history import SimpleHistoryAdmin

from ..admin_site import meta_consent_admin
from ..forms import SubjectConsentV1Form
from ..models import SubjectConsentV1
from .modeladmin_mixins import SubjectConsentModelAdminMixin


@admin.register(SubjectConsentV1, site=meta_consent_admin)
class SubjectConsentV1Admin(
    SubjectConsentModelAdminMixin,
    ModelAdminConsentMixin,
    ModelAdminSubjectDashboardMixin,
    SimpleHistoryAdmin,
):
    form = SubjectConsentV1Form



from django.contrib import admin
from django_audit_fields.admin import audit_fieldset_tuple
from edc_crf.fieldset import crf_status_fieldset
from edc_form_label.form_label_modeladmin_mixin import FormLabelModelAdminMixin
from edc_model_admin.history import SimpleHistoryAdmin

from ..admin_site import meta_subject_admin
from ..forms import FollowupVitalsForm
from ..models import FollowupVitals
from .fields import get_blood_pressure_fields, get_respiratory_o2_fields
from .modeladmin import CrfModelAdminMixin


@admin.register(FollowupVitals, site=meta_subject_admin)
class FollowupVitalsAdmin(CrfModelAdminMixin, FormLabelModelAdminMixin, SimpleHistoryAdmin):
    form = FollowupVitalsForm

    additional_instructions = (
        "If participant is pregnant, complete the action linked CRF `Pregnancy notification`."
    )

    fieldsets = (
        (None, {"fields": ("subject_visit", "report_datetime")}),
        (
            "Weight",
            {
                "fields": ("weight",),
            },
        ),
        (
            "Waist circumference",
            {
                "description": (
                    "REQUIRED at 36 and 48 months. If not measured "
                    "at 36 and 48 months, provide the reason."
                ),
                "fields": (
                    "waist_circumference_measured",
                    "waist_circumference",
                    "waist_circumference_comment",
                ),
            },
        ),
        (
            "BP and heart rate",
            {
                "description": (
                    "To be completed by the research nurse. <BR>"
                    "Refer to SOP for blood pressure measurement procedure."
                ),
                "fields": (
                    *get_blood_pressure_fields(),
                    "heart_rate",
                    *get_respiratory_o2_fields(),
                ),
            },
        ),
        (
            "Temperature",
            {
                "fields": ("temperature",),
            },
        ),
        crf_status_fieldset,
        audit_fieldset_tuple,
    )

    filter_horizontal = ()

    radio_fields = {  # noqa: RUF012
        "waist_circumference_measured": admin.VERTICAL,
        "severe_htn": admin.VERTICAL,
    }



# Generated by Django 3.2.4 on 2021-08-01 17:21

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0068_auto_20210728_1809"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalmnsi",
            name="calculated_patient_history_score",
            field=models.IntegerField(
                blank=True,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(13),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="calculated_physical_assessment_score",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                max_digits=3,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(10.0),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="calculated_patient_history_score",
            field=models.IntegerField(
                blank=True,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(13),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="calculated_physical_assessment_score",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                max_digits=3,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(10.0),
                ],
            ),
        ),
    ]



from .signals import subject_consent_on_post_delete, subject_consent_on_post_save
from .subject_consent import SubjectConsent
from .subject_consent_v1 import SubjectConsentV1
from .subject_consent_v1_ext import SubjectConsentV1Ext
from .subject_reconsent import SubjectReconsent

__all__ = [
    "SubjectConsent",
    "SubjectConsentV1",
    "SubjectConsentV1Ext",
    "SubjectReconsent",
    "subject_consent_on_post_delete",
    "subject_consent_on_post_save",
]



from clinicedc_constants import NO, YES
from django import forms
from edc_form_validators import FormValidator, FormValidatorMixin
from edc_glucose.form_validators import OgttFormValidatorMixin
from edc_glucose.utils import validate_glucose_as_millimoles_per_liter

from ..models import MissingOgttNote


class MissingOgttNoteFormValidator(OgttFormValidatorMixin, FormValidator):
    def clean(self):
        self.applicable_if(YES, field="result_status", field_applicable="fasting")
        self.required_if(YES, NO, field="fasting", field_required="ogtt_base_datetime")
        self.required_if(YES, NO, field="fasting", field_required="ogtt_datetime")
        self.required_if(YES, NO, field="fasting", field_required="ogtt_value")
        self.applicable_if(YES, NO, field="fasting", field_applicable="ogtt_units")
        validate_glucose_as_millimoles_per_liter("ogtt", self.cleaned_data)
        self.validate_ogtt_dates()
        self.validate_ogtt_time_interval()


class MissingOgttNoteForm(FormValidatorMixin, forms.ModelForm):
    form_validator_cls = MissingOgttNoteFormValidator

    class Meta:
        model = MissingOgttNote
        fields = "__all__"
        help_text = {"subject_identifier": "(read-only)", "name": "(read-only)"}  # noqa: RUF012
        widgets = {  # noqa: RUF012
            "report_model": forms.TextInput(attrs={"readonly": "readonly"}),
            "subject_identifier": forms.TextInput(attrs={"readonly": "readonly"}),
        }



from clinicedc_constants import NO, OTHER, YES


class ArvHistoryFormValidatorMixin:
    def validate_arv_history_fields(self):
        self.date_not_before(
            "arv_initiation_date",
            "viral_load_date",
            "Invalid. Cannot be before ARV initiation date.",
        )

        self.date_not_before(
            "arv_initiation_date",
            "current_arv_regimen_date",
            "Invalid. Cannot be before ARV initiation date.",
        )

        self.required_if_not_none(
            "viral_load", "viral_load_date", field_required_evaluate_as_int=True
        )

        self.date_not_before(
            "hiv_diagnosis_date",
            "viral_load_date",
            "Invalid. Cannot be before HIV diagnosis date.",
        )

        self.required_if_not_none("cd4", "cd4_date", field_required_evaluate_as_int=True)

        self.date_not_before(
            "hiv_diagnosis_date",
            "cd4_date",
            "Invalid. Cannot be before HIV diagnosis date.",
        )

        self.required_if(
            OTHER,
            field="current_arv_regimen",
            field_required="other_current_arv_regimen",
        )

        self.required_if(
            YES, field="has_previous_arv_regimen", field_required="previous_arv_regimen"
        )

        if self.cleaned_data.get("has_previous_arv_regimen") == NO:
            self.date_equal(
                "arv_initiation_date",
                "current_arv_regimen_start_date",
                "Invalid. Expected current regimen date to equal initiation date.",
            )

        self.required_if(
            YES, field="has_previous_arv_regimen", field_required="previous_arv_regimen"
        )

        self.required_if(
            OTHER,
            field="previous_arv_regimen",
            field_required="other_previous_arv_regimen",
        )

        self.required_if(YES, field="on_oi_prophylaxis", field_required="oi_prophylaxis")

        self.m2m_other_specify(
            OTHER, m2m_field="oi_prophylaxis", field_other="other_oi_prophylaxis"
        )



from .health_economics_simple_admin import HealthEconomicsSimpleAdmin
from .health_economics_update_admin import HealthEconomicsUpdateAdmin

__all__ = ["HealthEconomicsSimpleAdmin", "HealthEconomicsUpdateAdmin"]



from django import forms
from edc_crf.modelform_mixins import CrfModelFormMixin

from ..form_validators import HivExitReviewFormValidator
from ..models import HivExitReview


class HivExitReviewForm(CrfModelFormMixin, forms.ModelForm):
    form_validator_cls = HivExitReviewFormValidator

    class Meta:
        model = HivExitReview
        fields = "__all__"



from django.contrib import admin
from django_audit_fields.admin import audit_fieldset_tuple
from edc_crf.fieldset import crf_status_fieldset
from edc_model_admin.history import SimpleHistoryAdmin
from edc_model_admin.mixins import TabularInlineMixin

from ..admin_site import meta_subject_admin
from ..forms import OtherArvRegimensDetailForm, OtherArvRegimensForm
from ..models import OtherArvRegimens, OtherArvRegimensDetail, PatientHistory
from .modeladmin import CrfModelAdminMixin


class OtherArvRegimensInlineAdmin(TabularInlineMixin, admin.TabularInline):
    model = OtherArvRegimensDetail
    form = OtherArvRegimensDetailForm
    extra = 1
    view_on_site = False
    autocomplete_fields = ("arv_regimen",)

    fieldsets = (
        (
            "ARV Regimen History",
            {
                "description": (
                    "Do not include most recent two regimens reported on the "
                    f"`{PatientHistory._meta.verbose_name}` CRF"
                ),
                "fields": (
                    "arv_regimen",
                    "other_arv_regimen",
                    "arv_regimen_start_date",
                    "notes",
                ),
            },
        ),
    )


@admin.register(OtherArvRegimens, site=meta_subject_admin)
class OtherArvRegimensAdmin(CrfModelAdminMixin, SimpleHistoryAdmin):
    form = OtherArvRegimensForm

    inlines = (OtherArvRegimensInlineAdmin,)

    fieldsets = (
        (None, {"fields": ("subject_visit", "report_datetime", "has_other_regimens")}),
        crf_status_fieldset,
        audit_fieldset_tuple,
    )

    radio_fields = {  # noqa: RUF012
        "has_other_regimens": admin.VERTICAL,
    }



# Generated by Django 4.1.2 on 2022-11-30 18:01

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0157_remove_bloodresultsfbc_crf_status_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="followupexamination",
            name="attended_clinic",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Includes other routine appointments, e.g. BP check or family planning",
                max_length=25,
                verbose_name="Since the participant's last study visit did they attend any clinic or hospital for care for ANY reason",
            ),
        ),
        migrations.AlterField(
            model_name="followupexamination",
            name="attended_clinic_detail",
            field=models.TextField(
                blank=True,
                help_text="If the participant was given a referral letter or discharge summary record details here",
                null=True,
                verbose_name="If YES, attend clinic or hospital, please provide details of this event",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowupexamination",
            name="attended_clinic",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Includes other routine appointments, e.g. BP check or family planning",
                max_length=25,
                verbose_name="Since the participant's last study visit did they attend any clinic or hospital for care for ANY reason",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowupexamination",
            name="attended_clinic_detail",
            field=models.TextField(
                blank=True,
                help_text="If the participant was given a referral letter or discharge summary record details here",
                null=True,
                verbose_name="If YES, attend clinic or hospital, please provide details of this event",
            ),
        ),
    ]



# Generated by Django 5.2.6 on 2025-09-24 05:45

import django.utils.timezone
import django_revision.revision_field
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_consent", "0031_alter_historicalsubjectconsent_guardian_name_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="ethnicity",
            field=models.CharField(
                default="", editable=False, help_text="from screening", max_length=15
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="slug",
            field=models.CharField(
                db_index=True,
                default="",
                editable=False,
                help_text="Hold slug field values for quick search. Excludes encrypted fields",
                max_length=250,
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="subject_identifier_aka",
            field=models.CharField(
                default="",
                editable=False,
                help_text="track a previously allocated identifier.",
                max_length=50,
                verbose_name="Subject Identifier a.k.a",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1",
            name="ethnicity",
            field=models.CharField(
                default="", editable=False, help_text="from screening", max_length=15
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1",
            name="slug",
            field=models.CharField(
                db_index=True,
                default="",
                editable=False,
                help_text="Hold slug field values for quick search. Excludes encrypted fields",
                max_length=250,
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1",
            name="subject_identifier_aka",
            field=models.CharField(
                default="",
                editable=False,
                help_text="track a previously allocated identifier.",
                max_length=50,
                verbose_name="Subject Identifier a.k.a",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1ext",
            name="action_identifier",
            field=models.CharField(
                blank=True, db_index=True, default="", max_length=50
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1ext",
            name="action_item_reason",
            field=models.TextField(default="", editable=False),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1ext",
            name="consent_extension_definition_name",
            field=models.CharField(
                default="",
                editable=False,
                max_length=50,
                verbose_name="Consent extension definition",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1ext",
            name="consent_extension_version",
            field=models.CharField(
                default="",
                editable=False,
                max_length=10,
                verbose_name="Consent extension version",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1ext",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1ext",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1ext",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1ext",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1ext",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1ext",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1ext",
            name="report_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1ext",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1ext",
            name="subject_identifier_aka",
            field=models.CharField(
                default="",
                editable=False,
                help_text="track a previously allocated identifier.",
                max_length=50,
                verbose_name="Subject Identifier a.k.a",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectreconsent",
            name="action_identifier",
            field=models.CharField(
                blank=True, db_index=True, default="", max_length=50
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectreconsent",
            name="action_item_reason",
            field=models.TextField(default="", editable=False),
        ),
        migrations.AlterField(
            model_name="historicalsubjectreconsent",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectreconsent",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectreconsent",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectreconsent",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectreconsent",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectreconsent",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectreconsent",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectreconsent",
            name="slug",
            field=models.CharField(
                db_index=True,
                default="",
                editable=False,
                help_text="Hold slug field values for quick search. Excludes encrypted fields",
                max_length=250,
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectreconsent",
            name="subject_identifier_aka",
            field=models.CharField(
                default="",
                editable=False,
                help_text="track a previously allocated identifier.",
                max_length=50,
                verbose_name="Subject Identifier a.k.a",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="ethnicity",
            field=models.CharField(
                default="", editable=False, help_text="from screening", max_length=15
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="slug",
            field=models.CharField(
                db_index=True,
                default="",
                editable=False,
                help_text="Hold slug field values for quick search. Excludes encrypted fields",
                max_length=250,
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="subject_identifier_aka",
            field=models.CharField(
                default="",
                editable=False,
                help_text="track a previously allocated identifier.",
                max_length=50,
                verbose_name="Subject Identifier a.k.a",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsentv1ext",
            name="action_identifier",
            field=models.CharField(blank=True, default="", max_length=50, unique=True),
        ),
        migrations.AlterField(
            model_name="subjectconsentv1ext",
            name="action_item_reason",
            field=models.TextField(default="", editable=False),
        ),
        migrations.AlterField(
            model_name="subjectconsentv1ext",
            name="consent_extension_definition_name",
            field=models.CharField(
                default="",
                editable=False,
                max_length=50,
                verbose_name="Consent extension definition",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsentv1ext",
            name="consent_extension_version",
            field=models.CharField(
                default="",
                editable=False,
                max_length=10,
                verbose_name="Consent extension version",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsentv1ext",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsentv1ext",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsentv1ext",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsentv1ext",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsentv1ext",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsentv1ext",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsentv1ext",
            name="report_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="subjectconsentv1ext",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsentv1ext",
            name="subject_identifier_aka",
            field=models.CharField(
                default="",
                editable=False,
                help_text="track a previously allocated identifier.",
                max_length=50,
                verbose_name="Subject Identifier a.k.a",
            ),
        ),
        migrations.AlterField(
            model_name="subjectreconsent",
            name="action_identifier",
            field=models.CharField(blank=True, default="", max_length=50, unique=True),
        ),
        migrations.AlterField(
            model_name="subjectreconsent",
            name="action_item_reason",
            field=models.TextField(default="", editable=False),
        ),
        migrations.AlterField(
            model_name="subjectreconsent",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="subjectreconsent",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="subjectreconsent",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="subjectreconsent",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="subjectreconsent",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="subjectreconsent",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="subjectreconsent",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="subjectreconsent",
            name="slug",
            field=models.CharField(
                db_index=True,
                default="",
                editable=False,
                help_text="Hold slug field values for quick search. Excludes encrypted fields",
                max_length=250,
            ),
        ),
        migrations.AlterField(
            model_name="subjectreconsent",
            name="subject_identifier_aka",
            field=models.CharField(
                default="",
                editable=False,
                help_text="track a previously allocated identifier.",
                max_length=50,
                verbose_name="Subject Identifier a.k.a",
            ),
        ),
    ]



CASE_EOS = 7
CASE_FBGS_WITH_FIRST_OGTT = 2
CASE_FBGS_WITH_SECOND_OGTT = 3
CASE_FBG_ONLY = 4
CASE_FBG_VERY_HIGH = 5
CASE_OGTT = 1
EOS_DM_MET = "EOS - Patient developed diabetes"
OGTT_THRESHOLD_MET = "OGTT >= 11.1"
FBG_BEYOND_THRESHOLD = 20.0
FBG_THRESHOLD_MET = f"FBG >= {FBG_BEYOND_THRESHOLD}"
endpoint_columns = [
    "subject_identifier",
    "site_id",
    "baseline_datetime",
    "visit_datetime",
    "interval_in_days",
    "visit_code",
    "fbg_value",
    "ogtt_value",
    "fbg_datetime",
    "fasted",
    "endpoint_label",
    "endpoint_type",
    "endpoint",
    "offstudy_datetime",
    "offstudy_reason",
]

endpoint_cases = {
    CASE_OGTT: OGTT_THRESHOLD_MET,
    CASE_FBGS_WITH_FIRST_OGTT: "FBG >= 7 x 2, first OGTT<=11.1",
    CASE_FBGS_WITH_SECOND_OGTT: "FBG >= 7 x 2, second OGTT<=11.1",
    CASE_FBG_ONLY: "FBG >= 7 x 2, OGTT not considered",
    CASE_FBG_VERY_HIGH: FBG_THRESHOLD_MET,
    CASE_EOS: EOS_DM_MET,
}



# Generated by Django 5.2.6 on 2025-09-30 05:07

import _socket
import django.db.models.deletion
import django.db.models.manager
import django.utils.timezone
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_revision.revision_field
import edc_sites.managers
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "meta_rando",
            "0006_alter_historicalrandomizationlist_allocated_user_and_more",
        ),
        ("sites", "0002_alter_domain_unique"),
    ]

    operations = [
        migrations.CreateModel(
            name="SpfqList",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        default="",
                        editable=False,
                        help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                        max_length=75,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(blank=True, default=django.utils.timezone.now),
                ),
                (
                    "modified",
                    models.DateTimeField(blank=True, default=django.utils.timezone.now),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        default="",
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        default="",
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                        verbose_name="Hostname created",
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        default="",
                        help_text="System field. (modified on every save)",
                        max_length=50,
                        verbose_name="Hostname modified",
                    ),
                ),
                (
                    "device_created",
                    models.CharField(
                        blank=True,
                        default="",
                        max_length=10,
                        verbose_name="Device created",
                    ),
                ),
                (
                    "device_modified",
                    models.CharField(
                        blank=True,
                        default="",
                        max_length=10,
                        verbose_name="Device modified",
                    ),
                ),
                (
                    "locale_created",
                    models.CharField(
                        blank=True,
                        default="",
                        help_text="Auto-updated by Modeladmin",
                        max_length=10,
                        verbose_name="Locale created",
                    ),
                ),
                (
                    "locale_modified",
                    models.CharField(
                        blank=True,
                        default="",
                        help_text="Auto-updated by Modeladmin",
                        max_length=10,
                        verbose_name="Locale modified",
                    ),
                ),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("subject_identifier", models.CharField(max_length=50, unique=True)),
                ("sid", models.IntegerField(unique=True)),
                ("last_visit_code", models.CharField(max_length=25)),
                ("last_appt_datetime", models.DateTimeField()),
                (
                    "gender",
                    models.CharField(
                        choices=[("M", "Male"), ("F", "Female")], max_length=10
                    ),
                ),
                (
                    "weight_bin",
                    models.CharField(
                        choices=[
                            ("lt_35", "<35"),
                            ("gte_35__lte_49", "35-49"),
                            ("gte_50", ">=50"),
                        ],
                        max_length=25,
                    ),
                ),
                ("date_generated", models.DateTimeField()),
                (
                    "site",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "verbose_name": "SPFQ List",
                "verbose_name_plural": "SPFQ List",
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "default_manager_name": "objects",
                "indexes": [
                    models.Index(
                        fields=["modified", "created"],
                        name="meta_rando__modifie_f4fcd8_idx",
                    ),
                    models.Index(
                        fields=["user_modified", "user_created"],
                        name="meta_rando__user_mo_79b855_idx",
                    ),
                ],
            },
            managers=[
                ("on_site", edc_sites.managers.CurrentSiteManager()),
                ("objects", django.db.models.manager.Manager()),
            ],
        ),
    ]



# Generated by Django 5.0.8 on 2024-08-27 19:22

from django.db import migrations
from django.db.migrations import RunPython
from clinicedc_constants import NO, YES


def update_old_fasting_choices(apps, schema_editor):
    result = {"fasting": 0, "non_fasting": 0}
    model_cls = apps.get_model("meta_subject.glucosefbg")
    result["fasting"] = model_cls.objects.filter(fasting="fasting").update(fasting=YES)
    result["non_fasting"] = model_cls.objects.filter(fasting="non_fasting").update(fasting=NO)
    print(f"Updated: results are {result}")
    print("Done.")


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0211_dmendpoint_endpoint_reached_and_more"),
    ]

    operations = [RunPython(update_old_fasting_choices)]



from django.contrib import admin
from edc_action_item.fieldsets import action_fieldset_tuple
from edc_lab_results.admin import BloodResultsModelAdminMixin
from edc_lab_results.fieldsets import BloodResultFieldset
from edc_model_admin.history import SimpleHistoryAdmin

from ...admin_site import meta_subject_admin
from ...forms import BloodResultsLipidsForm
from ...models import BloodResultsLipids
from ..modeladmin import CrfModelAdminMixin


@admin.register(BloodResultsLipids, site=meta_subject_admin)
class BloodResultsLipidsAdmin(
    BloodResultsModelAdminMixin, CrfModelAdminMixin, SimpleHistoryAdmin
):
    form = BloodResultsLipidsForm
    fieldsets = BloodResultFieldset(
        BloodResultsLipids.lab_panel,
        model_cls=BloodResultsLipids,
        extra_fieldsets=[
            (-1, action_fieldset_tuple),
        ],
    ).fieldsets



# Generated by Django 5.0.8 on 2024-08-23 13:59

import _socket
import django.db.models.deletion
import django.db.models.manager
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django.utils.timezone
import django_revision.revision_field
import edc_model.validators.date
import edc_sites.managers
import edc_utils.date
import simple_history.models
import uuid
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_reports", "0034_auto_20240823_1642"),
        ("sites", "0002_alter_domain_unique"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name="HistoricalMissingOgttNote",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(blank=True, default=django.utils.timezone.now),
                ),
                (
                    "modified",
                    models.DateTimeField(blank=True, default=django.utils.timezone.now),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                        verbose_name="Hostname created",
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                        verbose_name="Hostname modified",
                    ),
                ),
                (
                    "device_created",
                    models.CharField(blank=True, max_length=10, verbose_name="Device created"),
                ),
                (
                    "device_modified",
                    models.CharField(
                        blank=True, max_length=10, verbose_name="Device modified"
                    ),
                ),
                (
                    "locale_created",
                    models.CharField(
                        blank=True,
                        help_text="Auto-updated by Modeladmin",
                        max_length=10,
                        null=True,
                        verbose_name="Locale created",
                    ),
                ),
                (
                    "locale_modified",
                    models.CharField(
                        blank=True,
                        help_text="Auto-updated by Modeladmin",
                        max_length=10,
                        null=True,
                        verbose_name="Locale modified",
                    ),
                ),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                ("subject_identifier", models.CharField(db_index=True, max_length=50)),
                ("report_model", models.CharField(max_length=150)),
                ("report_datetime", models.DateTimeField(default=edc_utils.date.get_utcnow)),
                ("note", models.TextField(blank=True, null=True)),
                (
                    "ogtt_base_datetime",
                    models.DateTimeField(
                        blank=True,
                        help_text="(glucose solution given)",
                        null=True,
                        validators=[edc_model.validators.date.datetime_not_future],
                        verbose_name="Date/time oral glucose solution given",
                    ),
                ),
                (
                    "ogtt_value",
                    models.DecimalField(
                        blank=True,
                        decimal_places=2,
                        help_text="A `HIGH` reading may be entered as 9999.99",
                        max_digits=8,
                        null=True,
                        verbose_name="Blood glucose measure 2hrs <u>after</u> oral glucose solution given",
                    ),
                ),
                (
                    "ogtt_quantifier",
                    models.CharField(
                        choices=[
                            ("=", "="),
                            (">", ">"),
                            (">=", ">="),
                            ("<", "<"),
                            ("<=", "<="),
                        ],
                        default="=",
                        max_length=10,
                    ),
                ),
                (
                    "ogtt_units",
                    models.CharField(
                        choices=[
                            ("mg/dL", "mg/dL"),
                            ("mmol/L", "mmol/L (millimoles/L)"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=15,
                        verbose_name="Units (Blood glucose 2hrs after...)",
                    ),
                ),
                (
                    "ogtt_datetime",
                    models.DateTimeField(
                        blank=True,
                        help_text="(2 hours after glucose solution given)",
                        null=True,
                        validators=[edc_model.validators.date.datetime_not_future],
                        verbose_name="Date/time blood glucose measured 2hrs <u>after</u> oral glucose solution given",
                    ),
                ),
                (
                    "status",
                    models.CharField(
                        choices=[
                            ("done", "Done"),
                            ("PENDING", "Data is pending"),
                            ("not_available", "Data not available"),
                        ],
                        default="done",
                        max_length=25,
                    ),
                ),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4, editable=False, primary_key=True, serialize=False
                    ),
                ),
                ("history_date", models.DateTimeField(db_index=True)),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical Screening: Missing OGTT Note",
                "verbose_name_plural": "historical Screening: Missing OGTT Notes",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": ("history_date", "history_id"),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name="MissingOgttNote",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(blank=True, default=django.utils.timezone.now),
                ),
                (
                    "modified",
                    models.DateTimeField(blank=True, default=django.utils.timezone.now),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                        verbose_name="Hostname created",
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                        verbose_name="Hostname modified",
                    ),
                ),
                (
                    "device_created",
                    models.CharField(blank=True, max_length=10, verbose_name="Device created"),
                ),
                (
                    "device_modified",
                    models.CharField(
                        blank=True, max_length=10, verbose_name="Device modified"
                    ),
                ),
                (
                    "locale_created",
                    models.CharField(
                        blank=True,
                        help_text="Auto-updated by Modeladmin",
                        max_length=10,
                        null=True,
                        verbose_name="Locale created",
                    ),
                ),
                (
                    "locale_modified",
                    models.CharField(
                        blank=True,
                        help_text="Auto-updated by Modeladmin",
                        max_length=10,
                        null=True,
                        verbose_name="Locale modified",
                    ),
                ),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("subject_identifier", models.CharField(max_length=50, unique=True)),
                ("report_model", models.CharField(max_length=150)),
                ("report_datetime", models.DateTimeField(default=edc_utils.date.get_utcnow)),
                ("note", models.TextField(blank=True, null=True)),
                (
                    "ogtt_base_datetime",
                    models.DateTimeField(
                        blank=True,
                        help_text="(glucose solution given)",
                        null=True,
                        validators=[edc_model.validators.date.datetime_not_future],
                        verbose_name="Date/time oral glucose solution given",
                    ),
                ),
                (
                    "ogtt_value",
                    models.DecimalField(
                        blank=True,
                        decimal_places=2,
                        help_text="A `HIGH` reading may be entered as 9999.99",
                        max_digits=8,
                        null=True,
                        verbose_name="Blood glucose measure 2hrs <u>after</u> oral glucose solution given",
                    ),
                ),
                (
                    "ogtt_quantifier",
                    models.CharField(
                        choices=[
                            ("=", "="),
                            (">", ">"),
                            (">=", ">="),
                            ("<", "<"),
                            ("<=", "<="),
                        ],
                        default="=",
                        max_length=10,
                    ),
                ),
                (
                    "ogtt_units",
                    models.CharField(
                        choices=[
                            ("mg/dL", "mg/dL"),
                            ("mmol/L", "mmol/L (millimoles/L)"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=15,
                        verbose_name="Units (Blood glucose 2hrs after...)",
                    ),
                ),
                (
                    "ogtt_datetime",
                    models.DateTimeField(
                        blank=True,
                        help_text="(2 hours after glucose solution given)",
                        null=True,
                        validators=[edc_model.validators.date.datetime_not_future],
                        verbose_name="Date/time blood glucose measured 2hrs <u>after</u> oral glucose solution given",
                    ),
                ),
                (
                    "status",
                    models.CharField(
                        choices=[
                            ("done", "Done"),
                            ("PENDING", "Data is pending"),
                            ("not_available", "Data not available"),
                        ],
                        default="done",
                        max_length=25,
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "verbose_name": "Screening: Missing OGTT Note",
                "verbose_name_plural": "Screening: Missing OGTT Notes",
                "abstract": False,
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "default_manager_name": "objects",
                "indexes": [
                    models.Index(
                        fields=["modified", "created"], name="meta_report_modifie_4a4894_idx"
                    ),
                    models.Index(
                        fields=["user_modified", "user_created"],
                        name="meta_report_user_mo_5b8129_idx",
                    ),
                ],
            },
            managers=[
                ("on_site", edc_sites.managers.CurrentSiteManager()),
                ("objects", django.db.models.manager.Manager()),
            ],
        ),
    ]



# Generated by Django 3.2.13 on 2022-10-04 03:29

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_prn", "0049_auto_20220929_1742"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicaloffstudymedication",
            name="comment",
            field=models.TextField(
                blank=True, null=True, verbose_name="Any additional comments"
            ),
        ),
        migrations.AlterField(
            model_name="historicaloffstudymedication",
            name="reason_other",
            field=models.TextField(
                blank=True, null=True, verbose_name="If other, please specify ..."
            ),
        ),
        migrations.AlterField(
            model_name="offstudymedication",
            name="comment",
            field=models.TextField(
                blank=True, null=True, verbose_name="Any additional comments"
            ),
        ),
        migrations.AlterField(
            model_name="offstudymedication",
            name="reason_other",
            field=models.TextField(
                blank=True, null=True, verbose_name="If other, please specify ..."
            ),
        ),
    ]
